@@ -4,7 +4,8 @@ if VERSION < v"0.7-"
     error("Unsupported Julia version $VERSION")
 end
 
-using Pkg
+const Pkg =
+    Base.require(Base.PkgId(Base.UUID("44cfe95a-1eb2-52ea-b672-e2afdf69b78f"), "Pkg"))
 
 function cat_build_log(pkg)
     modpath = Base.locate_package(pkg)
@@ -22,7 +23,7 @@ Pkg.activate(compiler_env)
 @info "Installing PackageCompiler..."
 
 Pkg.add([
-    PackageSpec(
+    Pkg.PackageSpec(
         name = "PackageCompiler",
         uuid = "9b87118b-4619-50d2-8e1e-99f35a4d4d9d",
         version = "1",
